/////////////////////////////////////////////////////////////////////////////////////////
// FontTest.cpp
// Applied Data Systems
// (20-1134x)
//
// Description
// -----------
// This is a basic sample that shows how to draw and modify fonts on a Windows form.
// This application rotates a line of text while increasing and decreasing it's font size.
//
// History
// -------
// 20-11341 - Nov 27, 2002 : ctacke
//   Created initial implemetation
// 
/////////////////////////////////////////////////////////////////////////////////////////

#include <windows.h>
#include "resource.h"

// forward declarations
BOOL CALLBACK DialogProc(HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM lParam);
void CALLBACK TimerProc(HWND hwnd, UINT uMsg, UINT idEvent, DWORD dwTime );

// global variables
HWND	hwnd		= NULL;
HFONT	hf			= NULL;
LOGFONT	lf;
int		fontsize	= 8;
RECT	rect;

int WINAPI WinMain(	HINSTANCE hInstance,
					HINSTANCE hPrevInstance,
					LPTSTR    lpCmdLine,
					int       nCmdShow)
{
	MSG msg;

	// create our main dialog
	hwnd = CreateDialog(hInstance, 
		         MAKEINTRESOURCE (IDD_DIALOG1),
				 NULL,
				 (DLGPROC)DialogProc);

	// show the dialog
	ShowWindow(hwnd, nCmdShow);
	UpdateWindow(hwnd);

	// message pump
	while (GetMessage(&msg, NULL, 0, 0)) 
	{
		TranslateMessage(&msg);
		DispatchMessage(&msg);
	}

	return 0;
}

// Main Dialog callback
BOOL CALLBACK DialogProc (
                    HWND hwndDlg,
                    UINT uMsg,
                    WPARAM wParam,
                    LPARAM lParam)
{
	HDC             hdc;
	PAINTSTRUCT     ps;
	static UINT		timer	= 0;

	switch(uMsg)
	{
		case WM_PAINT:
			// draw our new text
			// this will have flicker - drawing to a bitmap and blitting it to the
			// screen would help
			hdc = BeginPaint(hwnd, &ps);
			GetWindowRect(hwnd, &rect);
			SelectObject (hdc, CreateFontIndirect(&lf)) ;
			DrawText(hdc, _T("Hello world!"), 12, &ps.rcPaint, DT_CENTER | DT_VCENTER);
			DeleteObject(SelectObject(hdc, GetStockObject(SYSTEM_FONT))) ;
			EndPaint (hwnd, &ps) ;
		break;
		case WM_INITDIALOG:
			// set up our initial font
			lf.lfHeight = fontsize;
			lf.lfWidth = 0;
			lf.lfWeight = 1;
			_tcscpy(lf.lfFaceName, _T("Tahoma"));
			lf.lfItalic = FALSE;
			lf.lfEscapement = 0;
			lf.lfStrikeOut = FALSE;
			lf.lfUnderline = FALSE;
			lf.lfCharSet = DEFAULT_CHARSET;
			lf.lfOutPrecision = OUT_DEFAULT_PRECIS;
			lf.lfClipPrecision = OUT_DEFAULT_PRECIS;
			lf.lfPitchAndFamily = DEFAULT_PITCH | FF_DONTCARE;
			lf.lfQuality = DEFAULT_QUALITY;		

			// set the draw color and background
			hdc = GetWindowDC(hwnd);
			SetBkMode(hdc, TRANSPARENT);
			SetTextColor(hdc, 0);
		break;
		case WM_COMMAND:
			switch (LOWORD(wParam))
			{
				case IDOK:
					if(! timer)
					{
						// start the font rotation
						InvalidateRect(hwnd, NULL, TRUE);
						timer = SetTimer(NULL, NULL, 30, TimerProc);
					}
					else
					{
						// stop font rotation
						KillTimer(NULL, timer);
						timer = 0;
					}
				break;
				case IDCANCEL:
					// end the app
					PostQuitMessage(0);
				break;
			}
		break;
		return TRUE;
	} // switch(uMsg)

	return FALSE;
}

// Timer function
void CALLBACK TimerProc(HWND hWnd, UINT uMsg, UINT idEvent, DWORD dwTime )
{
	static int	size = fontsize;
	static int	esc  = 0;
	static BOOL	grow = TRUE;

	if(esc >= 36000)
	{
		esc = 0;
	}

	esc += 10;

	if(size > 25)
		grow = FALSE;
	else if(size < 8)
		grow = TRUE;


	if(grow)
		size++;
	else
		size--;
	
	lf.lfHeight = size;
	lf.lfEscapement = esc;

	InvalidateRect(hwnd, &rect, TRUE);
	UpdateWindow(hwnd);
}